@@ -44,9 +44,9 @@ class Domoticz(IPlugin):
 		#log.msg("WAMP session data received (transport ID %s): %s" % (self._parent._transportid, payload))
 		log.msg("index :  %s" % (idex)		
 		for rs in self.configuration_plugin['param_dz']
-			if rs['ids'] == idex
-				bod == rs['boy']
-				resp = requests.get ('http://192.168.0.3:8080/json.htm?type=command&param=switchlight&idx=%02d&switchcmd=%s&level=0' % (rs[idx],on_off.capitalize()))
+#			if rs['ids'] == idex
+#				bod == rs['boy']
+#				resp = requests.get ('http://192.168.0.3:8080/json.htm?type=command&param=switchlight&idx=%02d&switchcmd=%s&level=0' % (rs[idx],on_off.capitalize()))
 		return {"plugin": "Domoticz",
 			"method": "switchlight",
 			"body": bod
